@@ -27,13 +27,13 @@ class CreateProbeTasksRequest(AbstractModel):
         r"""
         :param _BatchTasks: 批量任务名-地址
         :type BatchTasks: list of ProbeTaskBasicConfiguration
-        :param _TaskType: 任务类型
+        :param _TaskType: 任务类型，如1、2、3、4、5、6、7；1-页面性能、2-文件上传、3-文件下载、4-端口性能、5-网络质量、6-音视频体验、7-域名whois
         :type TaskType: int
-        :param _Nodes: 拨测节点
+        :param _Nodes: 拨测节点，如10001，具体拨测地域运营商对应的拨测点编号可联系云拨测确认。
         :type Nodes: list of str
         :param _Interval: 拨测间隔
         :type Interval: int
-        :param _Parameters: 拨测参数
+        :param _Parameters: 拨测参数，详细可参考云拨测官方文档,链接:https://cloud.tencent.com/document/product/248/87308#createprobetasks。
         :type Parameters: str
         :param _TaskCategory: 任务分类
 <li>1 = PC</li>
@@ -43,12 +43,14 @@ class CreateProbeTasksRequest(AbstractModel):
         :type Cron: str
         :param _Tag: 资源标签值
         :type Tag: list of Tag
-        :param _ProbeType: 测试类型，包含定时测试与即时测试
+        :param _ProbeType: 测试类型，包含定时测试与即时测试。0-定时拨测，其它表示即时拨测。
         :type ProbeType: int
-        :param _PluginSource: 插件类型
+        :param _PluginSource: 插件类型，如CDN，详情参考云拨测官方文档。
         :type PluginSource: str
         :param _ClientNum: 客户端ID
         :type ClientNum: str
+        :param _NodeIpType: 拨测点IP类型：0-不限制IP类型，1-IPv4，2-IPv6
+        :type NodeIpType: int
         """
         self._BatchTasks = None
         self._TaskType = None
@@ -61,6 +63,7 @@ class CreateProbeTasksRequest(AbstractModel):
         self._ProbeType = None
         self._PluginSource = None
         self._ClientNum = None
+        self._NodeIpType = None
 
     @property
     def BatchTasks(self):
@@ -150,6 +153,14 @@ class CreateProbeTasksRequest(AbstractModel):
     def ClientNum(self, ClientNum):
         self._ClientNum = ClientNum
 
+    @property
+    def NodeIpType(self):
+        return self._NodeIpType
+
+    @NodeIpType.setter
+    def NodeIpType(self, NodeIpType):
+        self._NodeIpType = NodeIpType
+
 
     def _deserialize(self, params):
         if params.get("BatchTasks") is not None:
@@ -173,6 +184,7 @@ class CreateProbeTasksRequest(AbstractModel):
         self._ProbeType = params.get("ProbeType")
         self._PluginSource = params.get("PluginSource")
         self._ClientNum = params.get("ClientNum")
+        self._NodeIpType = params.get("NodeIpType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -192,7 +204,7 @@ class CreateProbeTasksResponse(AbstractModel):
         r"""
         :param _TaskIDs: 任务ID列表
         :type TaskIDs: list of str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._TaskIDs = None
@@ -268,7 +280,7 @@ class DeleteProbeTaskResponse(AbstractModel):
         :param _Results: 任务执行结果
 注意：此字段可能返回 null，表示取不到有效值。
         :type Results: list of TaskResult
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Total = None
@@ -345,7 +357,7 @@ AnalyzeTaskType_MediaStream：音视频体验
         :type SortField: str
         :param _Ascending: true表示升序
         :type Ascending: bool
-        :param _SelectedFields: 选中字段
+        :param _SelectedFields: 选中字段，如ProbeTime、TransferTime、TransferSize等。
         :type SelectedFields: list of str
         :param _Offset: 起始取数位置
         :type Offset: int
@@ -365,7 +377,7 @@ AnalyzeTaskType_MediaStream：音视频体验
 	
 这里实际按拨测结果中的地区来填写即可
 
-国内一般是省级单位，如广东、广西、中国香港、新疆；直辖市则填北京、上海
+国内一般是省级单位，如广东、广西、中国香港；直辖市则填北京、上海
 
 境外一般是国家名，如澳大利亚、新加坡
         :type Districts: list of str
@@ -383,6 +395,8 @@ AnalyzeTaskType_MediaStream：音视频体验
         :type City: list of str
         :param _ScrollID: es scroll查询id
         :type ScrollID: str
+        :param _QueryFlag: 详情数据下载
+        :type QueryFlag: str
         """
         self._BeginTime = None
         self._EndTime = None
@@ -398,6 +412,7 @@ AnalyzeTaskType_MediaStream：音视频体验
         self._ErrorTypes = None
         self._City = None
         self._ScrollID = None
+        self._QueryFlag = None
 
     @property
     def BeginTime(self):
@@ -511,6 +526,14 @@ AnalyzeTaskType_MediaStream：音视频体验
     def ScrollID(self, ScrollID):
         self._ScrollID = ScrollID
 
+    @property
+    def QueryFlag(self):
+        return self._QueryFlag
+
+    @QueryFlag.setter
+    def QueryFlag(self, QueryFlag):
+        self._QueryFlag = QueryFlag
+
 
     def _deserialize(self, params):
         self._BeginTime = params.get("BeginTime")
@@ -527,6 +550,7 @@ AnalyzeTaskType_MediaStream：音视频体验
         self._ErrorTypes = params.get("ErrorTypes")
         self._City = params.get("City")
         self._ScrollID = params.get("ScrollID")
+        self._QueryFlag = params.get("QueryFlag")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -550,7 +574,7 @@ class DescribeDetailedSingleProbeDataResponse(AbstractModel):
         :type TotalNumber: int
         :param _ScrollID: es scroll查询的id
         :type ScrollID: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._DataSet = None
@@ -603,6 +627,106 @@ class DescribeDetailedSingleProbeDataResponse(AbstractModel):
         self._RequestId = params.get("RequestId")
 
 
+class DescribeInstantTasksRequest(AbstractModel):
+    """DescribeInstantTasks请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Limit: 数量
+        :type Limit: int
+        :param _Offset: 起始位置
+        :type Offset: int
+        """
+        self._Limit = None
+        self._Offset = None
+
+    @property
+    def Limit(self):
+        return self._Limit
+
+    @Limit.setter
+    def Limit(self, Limit):
+        self._Limit = Limit
+
+    @property
+    def Offset(self):
+        return self._Offset
+
+    @Offset.setter
+    def Offset(self, Offset):
+        self._Offset = Offset
+
+
+    def _deserialize(self, params):
+        self._Limit = params.get("Limit")
+        self._Offset = params.get("Offset")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeInstantTasksResponse(AbstractModel):
+    """DescribeInstantTasks返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Tasks: 任务
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Tasks: list of SingleInstantTask
+        :param _Total: 总数
+        :type Total: int
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._Tasks = None
+        self._Total = None
+        self._RequestId = None
+
+    @property
+    def Tasks(self):
+        return self._Tasks
+
+    @Tasks.setter
+    def Tasks(self, Tasks):
+        self._Tasks = Tasks
+
+    @property
+    def Total(self):
+        return self._Total
+
+    @Total.setter
+    def Total(self, Total):
+        self._Total = Total
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        if params.get("Tasks") is not None:
+            self._Tasks = []
+            for item in params.get("Tasks"):
+                obj = SingleInstantTask()
+                obj._deserialize(item)
+                self._Tasks.append(obj)
+        self._Total = params.get("Total")
+        self._RequestId = params.get("RequestId")
+
+
 class DescribeNodesRequest(AbstractModel):
     """DescribeNodes请求参数结构体
 
@@ -720,7 +844,7 @@ class DescribeNodesResponse(AbstractModel):
         :param _NodeSet: 节点列表
 注意：此字段可能返回 null，表示取不到有效值。
         :type NodeSet: list of NodeDefineExt
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._NodeSet = None
@@ -767,9 +891,9 @@ AnalyzeTaskType_Transport：端口性能
 AnalyzeTaskType_UploadDownload：文件传输
 AnalyzeTaskType_MediaStream：音视频体验
         :type AnalyzeTaskType: str
-        :param _MetricType: 指标类型，指标查询默认传gauge
+        :param _MetricType: 指标类型（counter、gauge以及histogram），指标查询默认传gauge
         :type MetricType: str
-        :param _Field: 指标详细字段，可以传递传具体的指标也可以对指标进行聚合查询例如："avg(ping_time)"代表整体时延(ms)
+        :param _Field: 指标详细字段，可以传递传具体的指标也可以对指标进行聚合查询例如："avg(ping_time)"代表整体时延(ms)；不同的任务类型支持不同的field查询，以及聚合规则，详情可见https://cloud.tencent.com/document/product/248/87584。
         :type Field: str
         :param _Filter: 过滤条件可以传单个过滤条件也可以拼接多个参数
         :type Filter: str
@@ -859,10 +983,9 @@ class DescribeProbeMetricDataResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _MetricSet: 返回指标 JSON 序列化后的字符串,具体如下所示：
-"[{\"name\":\"task_navigate_request_gauge\",\"columns\":[\"time\",\"avg(first_screen_time) / 1000\"],\"values\":[[1641571200,6.756600000000001]],\"tags\":null}]"
+        :param _MetricSet:  返回指标 JSON 序列化后的字符串，具体如下所示："[{\"name\":\"task_navigate_request_gauge\",\"columns\":[\"time\",\"avg(first_screen_time) / 1000\"],\"values\":[[1641571200,6.756600000000001]],\"tags\":null}]"
         :type MetricSet: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._MetricSet = None
@@ -989,7 +1112,7 @@ class DescribeProbeNodesResponse(AbstractModel):
         :param _NodeSet: 节点列表
 注意：此字段可能返回 null，表示取不到有效值。
         :type NodeSet: list of NodeDefine
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._NodeSet = None
@@ -1238,7 +1361,7 @@ class DescribeProbeTasksResponse(AbstractModel):
         :type TaskSet: list of ProbeTask
         :param _Total: 任务总数
         :type Total: int
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._TaskSet = None
@@ -1837,6 +1960,9 @@ class ProbeTask(AbstractModel):
         :type TaskType: int
         :param _Nodes: 拨测节点列表
         :type Nodes: list of str
+        :param _NodeIpType: 拨测任务所选的拨测点IP类型，0-不限，1-IPv4，2-IPv6
+注意：此字段可能返回 null，表示取不到有效值。
+        :type NodeIpType: int
         :param _Interval: 拨测间隔
         :type Interval: int
         :param _Parameters: 拨测参数
@@ -1885,6 +2011,7 @@ class ProbeTask(AbstractModel):
         self._TaskId = None
         self._TaskType = None
         self._Nodes = None
+        self._NodeIpType = None
         self._Interval = None
         self._Parameters = None
         self._Status = None
@@ -1929,6 +2056,14 @@ class ProbeTask(AbstractModel):
     def Nodes(self, Nodes):
         self._Nodes = Nodes
 
+    @property
+    def NodeIpType(self):
+        return self._NodeIpType
+
+    @NodeIpType.setter
+    def NodeIpType(self, NodeIpType):
+        self._NodeIpType = NodeIpType
+
     @property
     def Interval(self):
         return self._Interval
@@ -2023,6 +2158,7 @@ class ProbeTask(AbstractModel):
         self._TaskId = params.get("TaskId")
         self._TaskType = params.get("TaskType")
         self._Nodes = params.get("Nodes")
+        self._NodeIpType = params.get("NodeIpType")
         self._Interval = params.get("Interval")
         self._Parameters = params.get("Parameters")
         self._Status = params.get("Status")
@@ -2142,7 +2278,7 @@ class ResumeProbeTaskResponse(AbstractModel):
         :param _Results: 任务执行详情
 注意：此字段可能返回 null，表示取不到有效值。
         :type Results: list of TaskResult
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Total = None
@@ -2195,6 +2331,123 @@ class ResumeProbeTaskResponse(AbstractModel):
         self._RequestId = params.get("RequestId")
 
 
+class SingleInstantTask(AbstractModel):
+    """单个即时拨测任务信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _TaskId: 任务ID
+        :type TaskId: str
+        :param _TargetAddress: 任务地址
+        :type TargetAddress: str
+        :param _TaskType: 任务类型
+        :type TaskType: int
+        :param _ProbeTime: 测试时间
+        :type ProbeTime: int
+        :param _Status: 任务状态
+        :type Status: str
+        :param _SuccessRate: 成功率
+        :type SuccessRate: float
+        :param _NodeCount: 节点数量
+        :type NodeCount: int
+        :param _TaskCategory: 节点类型
+        :type TaskCategory: int
+        """
+        self._TaskId = None
+        self._TargetAddress = None
+        self._TaskType = None
+        self._ProbeTime = None
+        self._Status = None
+        self._SuccessRate = None
+        self._NodeCount = None
+        self._TaskCategory = None
+
+    @property
+    def TaskId(self):
+        return self._TaskId
+
+    @TaskId.setter
+    def TaskId(self, TaskId):
+        self._TaskId = TaskId
+
+    @property
+    def TargetAddress(self):
+        return self._TargetAddress
+
+    @TargetAddress.setter
+    def TargetAddress(self, TargetAddress):
+        self._TargetAddress = TargetAddress
+
+    @property
+    def TaskType(self):
+        return self._TaskType
+
+    @TaskType.setter
+    def TaskType(self, TaskType):
+        self._TaskType = TaskType
+
+    @property
+    def ProbeTime(self):
+        return self._ProbeTime
+
+    @ProbeTime.setter
+    def ProbeTime(self, ProbeTime):
+        self._ProbeTime = ProbeTime
+
+    @property
+    def Status(self):
+        return self._Status
+
+    @Status.setter
+    def Status(self, Status):
+        self._Status = Status
+
+    @property
+    def SuccessRate(self):
+        return self._SuccessRate
+
+    @SuccessRate.setter
+    def SuccessRate(self, SuccessRate):
+        self._SuccessRate = SuccessRate
+
+    @property
+    def NodeCount(self):
+        return self._NodeCount
+
+    @NodeCount.setter
+    def NodeCount(self, NodeCount):
+        self._NodeCount = NodeCount
+
+    @property
+    def TaskCategory(self):
+        return self._TaskCategory
+
+    @TaskCategory.setter
+    def TaskCategory(self, TaskCategory):
+        self._TaskCategory = TaskCategory
+
+
+    def _deserialize(self, params):
+        self._TaskId = params.get("TaskId")
+        self._TargetAddress = params.get("TargetAddress")
+        self._TaskType = params.get("TaskType")
+        self._ProbeTime = params.get("ProbeTime")
+        self._Status = params.get("Status")
+        self._SuccessRate = params.get("SuccessRate")
+        self._NodeCount = params.get("NodeCount")
+        self._TaskCategory = params.get("TaskCategory")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SuspendProbeTaskRequest(AbstractModel):
     """SuspendProbeTask请求参数结构体
 
@@ -2243,7 +2496,7 @@ class SuspendProbeTaskResponse(AbstractModel):
         :param _Results: 任务执行结果
 注意：此字段可能返回 null，表示取不到有效值。
         :type Results: list of TaskResult
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Total = None
@@ -2409,7 +2662,7 @@ class UpdateProbeTaskAttributesRequest(AbstractModel):
         r"""
         :param _TaskId: 任务 ID
         :type TaskId: str
-        :param _Name: 任务名
+        :param _Name: 任务名，该参数为空时不作任何修改。
         :type Name: str
         """
         self._TaskId = None
@@ -2452,7 +2705,7 @@ class UpdateProbeTaskAttributesResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -2477,19 +2730,21 @@ class UpdateProbeTaskConfigurationListRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _TaskIds: 任务 ID
+        :param _TaskIds: 任务 ID，如task-n1wchki8
         :type TaskIds: list of str
-        :param _Nodes: 拨测节点
+        :param _Nodes: 拨测节点，如10001，详细地区运营商拨测编号请联系云拨测。
         :type Nodes: list of str
-        :param _Interval: 拨测间隔
+        :param _Interval: 拨测间隔，如30，单位为分钟。
         :type Interval: int
-        :param _Parameters: 拨测参数
+        :param _Parameters: 拨测参数，详细参数配置可参考云拨测官网文档。
         :type Parameters: str
         :param _Cron: 定时任务cron表达式
         :type Cron: str
         :param _ResourceIDs: 预付费套餐id
 需要与taskId对应
         :type ResourceIDs: list of str
+        :param _NodeIpType: 拨测节点的IP类型，0-不限，1-IPv4，2-IPv6
+        :type NodeIpType: int
         """
         self._TaskIds = None
         self._Nodes = None
@@ -2497,6 +2752,7 @@ class UpdateProbeTaskConfigurationListRequest(AbstractModel):
         self._Parameters = None
         self._Cron = None
         self._ResourceIDs = None
+        self._NodeIpType = None
 
     @property
     def TaskIds(self):
@@ -2546,6 +2802,14 @@ class UpdateProbeTaskConfigurationListRequest(AbstractModel):
     def ResourceIDs(self, ResourceIDs):
         self._ResourceIDs = ResourceIDs
 
+    @property
+    def NodeIpType(self):
+        return self._NodeIpType
+
+    @NodeIpType.setter
+    def NodeIpType(self, NodeIpType):
+        self._NodeIpType = NodeIpType
+
 
     def _deserialize(self, params):
         self._TaskIds = params.get("TaskIds")
@@ -2554,6 +2818,7 @@ class UpdateProbeTaskConfigurationListRequest(AbstractModel):
         self._Parameters = params.get("Parameters")
         self._Cron = params.get("Cron")
         self._ResourceIDs = params.get("ResourceIDs")
+        self._NodeIpType = params.get("NodeIpType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -2571,7 +2836,7 @@ class UpdateProbeTaskConfigurationListResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
